# afterpay-python
Python library for interacting with Afterpay API, based on the `braintree_python` project

## Note
This library may be functional but is still in development. Features still need to be tested
and code refactored.

## Dependencies
* requests
* certifi

This project has only been tested with Python 3.9